@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import shutil
 import sys
@@ -10,24 +24,33 @@ import inquirer
 import rich
 from lightning_cloud.openapi import V1LightningappInstanceState, V1LightningworkState
 from lightning_cloud.openapi.rest import ApiException
+from lightning_utilities.core.imports import RequirementCache
 from requests.exceptions import ConnectionError
 
+import lightning.app.core.constants as constants
 from lightning.app import __version__ as ver
 from lightning.app.cli import cmd_init, cmd_install, cmd_pl_init, cmd_react_ui_init
 from lightning.app.cli.cmd_apps import _AppManager
 from lightning.app.cli.cmd_clusters import AWSClusterManager
 from lightning.app.cli.commands.app_commands import _run_app_command
-from lightning.app.cli.commands.connection import (
+from lightning.app.cli.commands.cd import cd
+from lightning.app.cli.commands.cp import cp
+from lightning.app.cli.commands.logs import logs
+from lightning.app.cli.commands.ls import ls
+from lightning.app.cli.commands.pwd import pwd
+from lightning.app.cli.connect.app import (
     _list_app_commands,
     _retrieve_connection_to_an_app,
-    connect,
-    disconnect,
+    connect_app,
+    disconnect_app,
 )
-from lightning.app.cli.commands.logs import logs
+from lightning.app.cli.connect.data import connect_data
+from lightning.app.cli.connect.node import connect_node, disconnect_node
 from lightning.app.cli.lightning_cli_create import create
 from lightning.app.cli.lightning_cli_delete import delete
 from lightning.app.cli.lightning_cli_list import get_list
 from lightning.app.core.constants import DEBUG, ENABLE_APP_COMMENT_COMMAND_EXECUTION, get_lightning_cloud_url
+from lightning.app.runners.cloud import CloudRuntime
 from lightning.app.runners.runtime import dispatch
 from lightning.app.runners.runtime_type import RuntimeType
 from lightning.app.utilities.app_commands import run_app_commands
@@ -43,6 +66,7 @@ from lightning.app.utilities.exceptions import _ApiExceptionHandler, LogLinesLim
 from lightning.app.utilities.login import Auth
 from lightning.app.utilities.logs_socket_api import _ClusterLogsSocketAPI
 from lightning.app.utilities.network import LightningClient
+from lightning.app.utilities.port import _find_lit_app_port
 
 logger = Logger(__name__)
 
@@ -99,8 +123,27 @@ def show() -> None:
     pass
 
 
-_main.command()(connect)
-_main.command()(disconnect)
+@_main.group()
+def connect() -> None:
+    """Connect apps and data."""
+    pass
+
+
+@_main.group()
+def disconnect() -> None:
+    """Disconnect apps."""
+    pass
+
+
+connect.command("app")(connect_app)
+disconnect.command("app")(disconnect_app)
+connect.command("node", hidden=True)(connect_node)
+disconnect.command("node", hidden=True)(disconnect_node)
+connect.command("data", hidden=True)(connect_data)
+_main.command(hidden=True)(ls)
+_main.command(hidden=True)(cd)
+_main.command(hidden=True)(cp)
+_main.command(hidden=True)(pwd)
 show.command()(logs)
 
 
@@ -155,7 +198,7 @@ def cluster_logs(cluster_id: str, to_time: arrow.Arrow, from_time: arrow.Arrow,
             $ lightning show cluster logs my-cluster --limit 10
     """
 
-    client = LightningClient()
+    client = LightningClient(retry=False)
     cluster_manager = AWSClusterManager()
     existing_cluster_list = cluster_manager.get_clusters()
 
@@ -214,7 +257,7 @@ def login() -> None:
 def logout() -> None:
     """Log out of your lightning.ai account."""
     Auth().clear()
-    disconnect(logout=True)
+    disconnect_app(logout=True)
 
 
 def _run_app(
@@ -229,11 +272,12 @@ def _run_app(
     env: tuple,
     secret: tuple,
     run_app_comment_commands: bool,
+    enable_basic_auth: str,
 ) -> None:
 
     if not os.path.exists(file):
         original_file = file
-        file = cmd_install.gallery_apps_and_components(file, True, "latest", overwrite=False)  # type: ignore[assignment]  # noqa E501
+        file = cmd_install.gallery_apps_and_components(file, True, "latest", overwrite=True)  # type: ignore[assignment]  # noqa E501
         if file is None:
             click.echo(f"The provided entrypoint `{original_file}` doesn't exist.")
             sys.exit(1)
@@ -265,6 +309,9 @@ def _run_app(
 
     secrets = _format_input_env_variables(secret)
 
+    port = _find_lit_app_port(constants.APP_SERVER_PORT)
+    constants.APP_SERVER_PORT = port
+
     click.echo("Your Lightning App is starting. This won't take long.")
 
     # TODO: Fixme when Grid utilities are available.
@@ -282,6 +329,8 @@ def _run_app(
         secrets=secrets,
         cluster_id=cluster_id,
         run_app_comment_commands=run_app_comment_commands,
+        enable_basic_auth=enable_basic_auth,
+        port=port,
     )
     if runtime_type == RuntimeType.CLOUD:
         click.echo("Application is ready in the cloud")
@@ -327,6 +376,12 @@ def run() -> None:
     default=False,
     help="run environment setup commands from the app comments.",
 )
+@click.option(
+    "--enable-basic-auth",
+    type=str,
+    default="",
+    help="Enable basic authentication for the app and use credentials provided in the format username:password",
+)
 def run_app(
     file: str,
     cloud: bool,
@@ -340,6 +395,7 @@ def run_app(
     secret: tuple,
     app_args: tuple,
     run_app_comment_commands: bool,
+    enable_basic_auth: str,
 ) -> None:
     """Run an app from a file."""
     _run_app(
@@ -354,19 +410,35 @@ def run_app(
         env,
         secret,
         run_app_comment_commands,
+        enable_basic_auth,
     )
 
 
-@_main.group(hidden=True)
-def fork() -> None:
-    """Fork an application."""
-    pass
+if RequirementCache("lightning-fabric>=1.9.0") or RequirementCache("lightning>=1.9.0"):
+    # note it is automatically replaced to `from lightning.fabric.cli` when building monolithic/mirror package
+    from lightning.fabric.cli import _run_model
+
+    run.add_command(_run_model)
 
 
-@_main.group(hidden=True)
-def stop() -> None:
-    """Stop your application."""
-    pass
+@_main.command("open", hidden=True)
+@click.argument("path", type=str, default=".")
+@click.option(
+    "--cluster-id",
+    type=str,
+    default=None,
+    help="Open on a specific Lightning AI BYOC compute cluster",
+)
+@click.option("--name", help="The name to use for the CloudSpace", default="", type=str)
+def open(path: str, cluster_id: str, name: str) -> None:
+    """Open files or folders from your machine in a Lightning CloudSpace."""
+
+    if not os.path.exists(path):
+        click.echo(f"The provided path `{path}` doesn't exist.")
+        sys.exit(1)
+
+    runtime = CloudRuntime(entrypoint=Path(path))
+    runtime.open(name, cluster_id)
 
 
 _main.add_command(get_list)
