@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
@@ -147,33 +161,28 @@ class LightningTrainerScript(LightningFlow):
                 the ServableModule API
         """
         super().__init__()
-        self.ws = structures.List()
-        self.has_initialized = False
         self.script_path = script_path
         self.script_args = script_args
         self.num_nodes = num_nodes
-        self._cloud_compute = cloud_compute  # TODO: Add support for cloudCompute
         self.sanity_serving = sanity_serving
         self._script_runner = script_runner
         self._script_runner_kwargs = script_runner_kwargs
 
-    def run(self, **run_kwargs):
-        if not self.has_initialized:
-            for node_rank in range(self.num_nodes):
-                self.ws.append(
-                    self._script_runner(
-                        script_path=self.script_path,
-                        script_args=self.script_args,
-                        cloud_compute=self._cloud_compute,
-                        node_rank=node_rank,
-                        sanity_serving=self.sanity_serving,
-                        num_nodes=self.num_nodes,
-                        **self._script_runner_kwargs,
-                    )
+        self.ws = structures.List()
+        for node_rank in range(self.num_nodes):
+            self.ws.append(
+                self._script_runner(
+                    script_path=self.script_path,
+                    script_args=self.script_args,
+                    cloud_compute=cloud_compute,
+                    node_rank=node_rank,
+                    sanity_serving=self.sanity_serving,
+                    num_nodes=self.num_nodes,
+                    **self._script_runner_kwargs,
                 )
+            )
 
-            self.has_initialized = True
-
+    def run(self, **run_kwargs):
         for work in self.ws:
             if all(w.internal_ip for w in self.ws):
                 internal_urls = [(w.internal_ip, w.port) for w in self.ws]
