@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import inspect
 import warnings
 from copy import deepcopy
@@ -7,6 +21,7 @@ from typing import Any, cast, Dict, Generator, Iterable, List, Optional, Tuple,
 
 from deepdiff import DeepHash
 
+from lightning.app.core.plugin import Plugin
 from lightning.app.core.work import LightningWork
 from lightning.app.frontend import Frontend
 from lightning.app.storage import Path
@@ -726,6 +741,22 @@ class LightningFlow:
         """
         raise NotImplementedError
 
+    def configure_plugins(self) -> Optional[List[Dict[str, Plugin]]]:
+        """Configure the plugins of this LightningFlow.
+
+        Returns a list of dictionaries mapping a plugin name to a :class:`lightning.app.core.plugin.Plugin`.
+
+        .. code-block:: python
+
+            class Flow(LightningFlow):
+                def __init__(self):
+                    super().__init__()
+
+                def configure_plugins(self):
+                    return [{"my_plugin_name": MyPlugin()}]
+        """
+        pass
+
     def state_dict(self):
         """Returns the current flow state but not its children."""
         return {
