@@ -1,9 +1,23 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import fnmatch
 import os
 from functools import partial
 from pathlib import Path
 from shutil import copy2, copystat, Error
-from typing import Callable, List, Optional, Set, Union
+from typing import Callable, List, Optional, Set, Tuple, Union
 
 from lightning.app.core.constants import DOT_IGNORE_FILENAME
 from lightning.app.utilities.app_helpers import Logger
@@ -122,7 +136,7 @@ def _filter_ignored(src: Path, patterns: Set[str], current_dir: Path, entries: L
     return [entry for entry in entries if str(relative_dir / entry.name) not in ignored_names]
 
 
-def _parse_lightningignore(lines: List[str]) -> Set[str]:
+def _parse_lightningignore(lines: Tuple[str]) -> Set[str]:
     """Creates a set that removes empty lines and comments."""
     lines = [ln.strip() for ln in lines]
     # removes first `/` character for posix and `\\` for windows
