@@ -15,32 +15,27 @@
 from abc import ABC
 from typing import List, Optional, Tuple, Union
 
-from lightning_utilities.core.rank_zero import rank_zero_deprecation, rank_zero_warn
-
-from lightning.lite.connector import _PLUGIN_INPUT as _LITE_PLUGIN_INPUT
-from lightning.lite.connector import _PRECISION_INPUT
-from lightning.lite.lite import LightningLite as _NewLightningLite
-from lightning.lite.plugins import CheckpointIO, ClusterEnvironment
-from lightning.lite.plugins import DeepSpeedPrecision as LiteDeepSpeedPrecision
-from lightning.lite.plugins import DoublePrecision as LiteDoublePrecision
-from lightning.lite.plugins import NativeMixedPrecision as LiteNativeMixedPrecision
-from lightning.lite.plugins import Precision as LitePrecision
-from lightning.lite.plugins import TPUBf16Precision as LiteTPUBf16Precision
-from lightning.lite.plugins import TPUPrecision as LiteTPUPrecision
-from lightning.lite.strategies import DataParallelStrategy as LiteDataParallelStrategy
-from lightning.lite.strategies import DDPShardedStrategy as LiteDDPShardedStrategy
-from lightning.lite.strategies import DDPSpawnShardedStrategy as LiteDDPSpawnShardedStrategy
-from lightning.lite.strategies import DDPSpawnStrategy as LiteDDPSpawnStrategy
-from lightning.lite.strategies import DDPStrategy as LiteDDPStrategy
-from lightning.lite.strategies import DeepSpeedStrategy as LiteDeepSpeedStrategy
-from lightning.lite.strategies import SingleDeviceStrategy as LiteSingleDeviceStrategy
-from lightning.lite.strategies import SingleTPUStrategy as LiteSingleTPUStrategy
-from lightning.lite.strategies import Strategy as LiteStrategy
-from lightning.lite.strategies import XLAStrategy
+from lightning.fabric import Fabric
+from lightning.fabric.connector import _PLUGIN_INPUT as _LITE_PLUGIN_INPUT
+from lightning.fabric.connector import _PRECISION_INPUT
+from lightning.fabric.plugins import CheckpointIO, ClusterEnvironment
+from lightning.fabric.plugins import DeepSpeedPrecision as LiteDeepSpeedPrecision
+from lightning.fabric.plugins import DoublePrecision as LiteDoublePrecision
+from lightning.fabric.plugins import MixedPrecision as LiteMixedPrecision
+from lightning.fabric.plugins import Precision as LitePrecision
+from lightning.fabric.plugins import TPUBf16Precision as LiteTPUBf16Precision
+from lightning.fabric.plugins import TPUPrecision as LiteTPUPrecision
+from lightning.fabric.strategies import DataParallelStrategy as LiteDataParallelStrategy
+from lightning.fabric.strategies import DDPStrategy as LiteDDPStrategy
+from lightning.fabric.strategies import DeepSpeedStrategy as LiteDeepSpeedStrategy
+from lightning.fabric.strategies import SingleDeviceStrategy as LiteSingleDeviceStrategy
+from lightning.fabric.strategies import SingleTPUStrategy as LiteSingleTPUStrategy
+from lightning.fabric.strategies import Strategy as LiteStrategy
+from lightning.fabric.strategies import XLAStrategy
 from lightning.pytorch.accelerators import Accelerator as PLAccelerator
 from lightning.pytorch.plugins import DeepSpeedPrecisionPlugin as PLDeepSpeedPrecisionPlugin
 from lightning.pytorch.plugins import DoublePrecisionPlugin as PLDoublePrecisionPlugin
-from lightning.pytorch.plugins import NativeMixedPrecisionPlugin as PLNativeMixedPrecisionPlugin
+from lightning.pytorch.plugins import MixedPrecisionPlugin as PLMixedPrecisionPlugin
 from lightning.pytorch.plugins import PrecisionPlugin as PLPrecisionPlugin
 from lightning.pytorch.plugins import TPUBf16PrecisionPlugin as PLTPUBf16PrecisionPlugin
 from lightning.pytorch.plugins import TPUPrecisionPlugin as PLTPUPrecisionPlugin
@@ -54,14 +49,20 @@ from lightning.pytorch.strategies import SingleDeviceStrategy as PLSingleDeviceS
 from lightning.pytorch.strategies import SingleTPUStrategy as PLSingleTPUStrategy
 from lightning.pytorch.strategies import Strategy as PLStrategy
 from lightning.pytorch.strategies import TPUSpawnStrategy as PLTPUSpawnStrategy
+from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation, rank_zero_warn
 
 _PL_PLUGIN = Union[PLPrecisionPlugin, ClusterEnvironment, CheckpointIO]
 _PL_PLUGIN_INPUT = Union[_PL_PLUGIN, str]
 
 
-class LightningLite(_NewLightningLite, ABC):
+class LightningLite(Fabric, ABC):
     """Lite accelerates your PyTorch training or inference code with minimal changes required.
 
+    .. deprecated:: v1.9.0
+        The `lightning.pytorch.lite.LightningLite` class was deprecated in v1.9.0 and will be renamed to
+        `lightning.fabric.Fabric` in v2.0.0. It is no longer part of the pure `lightning.pytorch` package, and now
+        lives in the main `lightning` package.
+
     - Automatic placement of models and data onto the device.
     - Automatic support for mixed and double precision (smaller memory footprint).
     - Seamless switching between hardware (CPU, GPU, TPU) and distributed training strategies
@@ -73,7 +74,7 @@ class LightningLite(_NewLightningLite, ABC):
         accelerator: The hardware to run on. Possible choices are:
             ``"cpu"``, ``"cuda"``, ``"mps"``, ``"gpu"``, ``"tpu"``, ``"auto"``.
         strategy: Strategy for how to run across multiple devices. Possible choices are:
-            ``"dp"``, ``"ddp"``, ``"ddp_spawn"``, ``"deepspeed"``, ``"ddp_sharded"``.
+            ``"dp"``, ``"ddp"``, ``"ddp_spawn"``, ``"deepspeed"``, ``"fsdp"``.
         devices: Number of devices to train on (``int``), which GPUs to train on (``list`` or ``str``), or ``"auto"``.
             The value applies per node.
         num_nodes: Number of GPU nodes for distributed training.
@@ -83,13 +84,13 @@ class LightningLite(_NewLightningLite, ABC):
         gpus: Provides the same function as the ``devices`` argument but implies ``accelerator="gpu"``.
 
             .. deprecated:: v1.8.0
-                ``gpus`` has been deprecated in v1.8.0 and will be removed in v1.10.0.
+                ``gpus`` has been deprecated in v1.8.0 and will be removed in v2.0.0.
                 Please use ``accelerator='gpu'`` and ``devices=x`` instead.
 
         tpu_cores: Provides the same function as the ``devices`` argument but implies ``accelerator="tpu"``.
 
             .. deprecated:: v1.8.0
-                ``tpu_cores`` has been deprecated in v1.8.0 and will be removed in v1.10.0.
+                ``tpu_cores`` has been deprecated in v1.8.0 and will be removed in v2.0.0.
                 Please use ``accelerator='tpu'`` and ``devices=x`` instead.
     """
 
@@ -105,6 +106,11 @@ class LightningLite(_NewLightningLite, ABC):
         tpu_cores: Optional[Union[List[int], str, int]] = None,
     ) -> None:
 
+        rank_zero_deprecation(
+            "The `lightning.pytorch.lite.LightningLite` class was deprecated in v1.9.0 and will be renamed to"
+            " `lightning.fabric.Fabric` in v2.0.0."
+        )
+
         if gpus is not None or tpu_cores is not None:
             devices, accelerator = _convert_deprecated_device_flags(
                 accelerator=accelerator,
@@ -123,6 +129,20 @@ class LightningLite(_NewLightningLite, ABC):
         else:
             lite_plugins = plugins
 
+        if type(strategy) in (PLDDPShardedStrategy, PLDDPSpawnShardedStrategy) or strategy in (
+            "ddp_sharded",
+            "ddp_sharded_spawn",
+        ):
+            spawn_message = ""
+            if type(strategy) is PLDDPSpawnShardedStrategy or strategy == "ddp_sharded_spawn":
+                spawn_message = ", start_method='spawn'"
+            raise RuntimeError(
+                "LightningLite's sharded implementation using FairScale has been removed in favor of PyTorch's FSDP."
+                " You can try"
+                f" `Fabric(strategy=FSDPStrategy(sharding_strategy=ShardingStrategy.SHARD_GRAD_OP{spawn_message}))`"
+                " which implements optimizer-only sharding à la ZeRO-2. Or full sharding with `Fabric(strategy='fsdp')`"
+            )
+
         super().__init__(
             accelerator=accelerator,
             strategy=(_to_lite_strategy(strategy) if isinstance(strategy, PLStrategy) else strategy),
@@ -146,12 +166,12 @@ def _convert_deprecated_device_flags(
     if gpus is not None:
         rank_zero_deprecation(
             f"Setting `Lite(gpus={gpus!r})` is deprecated in v1.8.0 and will be removed"
-            f" in v1.10.0. Please use `Lite(accelerator='gpu', devices={gpus!r})` instead."
+            f" in v2.0.0. Please use `Lite(accelerator='gpu', devices={gpus!r})` instead."
         )
     if tpu_cores is not None:
         rank_zero_deprecation(
             f"Setting `Lite(tpu_cores={tpu_cores!r})` is deprecated in v1.8.0 and will be removed"
-            f" in v1.10.0. Please use `Lite(accelerator='tpu', devices={tpu_cores!r})` instead."
+            f" in v2.0.0. Please use `Lite(accelerator='tpu', devices={tpu_cores!r})` instead."
         )
     deprecated_devices_specific_flag = gpus or tpu_cores
     if deprecated_devices_specific_flag and deprecated_devices_specific_flag not in ([], 0, "0"):
@@ -192,7 +212,7 @@ def _to_lite_strategy(strategy: PLStrategy) -> LiteStrategy:
         )
 
     if strategy_cls is PLDDPSpawnStrategy:
-        return LiteDDPSpawnStrategy(
+        return LiteDDPStrategy(
             accelerator=strategy.accelerator,
             parallel_devices=strategy.parallel_devices,
             cluster_environment=strategy.cluster_environment,
@@ -237,31 +257,6 @@ def _to_lite_strategy(strategy: PLStrategy) -> LiteStrategy:
             precision=_to_lite_precision(strategy.precision_plugin),
         )
 
-    if strategy_cls is PLDDPShardedStrategy:
-        return LiteDDPShardedStrategy(
-            accelerator=strategy.accelerator,
-            parallel_devices=strategy.parallel_devices,
-            cluster_environment=strategy.cluster_environment,
-            checkpoint_io=strategy.checkpoint_io,
-            precision=_to_lite_precision(strategy.precision_plugin),
-            process_group_backend=strategy.process_group_backend,
-            timeout=strategy._timeout,
-            **strategy._ddp_kwargs,
-        )
-
-    if strategy_cls is PLDDPSpawnShardedStrategy:
-        return LiteDDPSpawnShardedStrategy(
-            accelerator=strategy.accelerator,
-            parallel_devices=strategy.parallel_devices,
-            cluster_environment=strategy.cluster_environment,
-            checkpoint_io=strategy.checkpoint_io,
-            precision=_to_lite_precision(strategy.precision_plugin),
-            process_group_backend=strategy.process_group_backend,
-            timeout=strategy._timeout,
-            start_method=strategy._start_method,
-            **strategy._ddp_kwargs,
-        )
-
     if strategy_cls is PLSingleDeviceStrategy:
         return LiteSingleDeviceStrategy(
             device=strategy.root_device,
@@ -286,8 +281,8 @@ def _to_lite_precision(plugin: Optional[PLPrecisionPlugin]) -> LitePrecision:
     if type(plugin) is PLPrecisionPlugin:
         return LitePrecision()
 
-    if type(plugin) is PLNativeMixedPrecisionPlugin:
-        return LiteNativeMixedPrecision(
+    if type(plugin) is PLMixedPrecisionPlugin:
+        return LiteMixedPrecision(
             precision=plugin.precision, device=plugin.device, scaler=plugin.scaler  # type: ignore[arg-type]
         )
 
@@ -296,7 +291,7 @@ def _to_lite_precision(plugin: Optional[PLPrecisionPlugin]) -> LitePrecision:
 
     if type(plugin) is PLDeepSpeedPrecisionPlugin:
         return LiteDeepSpeedPrecision(
-            precision=plugin.precision, amp_type=plugin.amp_type, amp_level=plugin.amp_level  # type: ignore[arg-type]
+            precision=plugin.precision,  # type: ignore[arg-type]
         )
 
     if type(plugin) is PLTPUPrecisionPlugin:
@@ -308,6 +303,6 @@ def _to_lite_precision(plugin: Optional[PLPrecisionPlugin]) -> LitePrecision:
     # No backward compatibility for custom plugins / subclasses, as we can't re-instantiate these plugins
     raise TypeError(
         "You passed an unsupported plugin as input to Lite(plugins=...) or to a strategy. If you built a custom plugin,"
-        " please change it to subclass the `lightning.lite.plugins.precision.Precision` class. Otherwise, please open"
+        " please change it to subclass the `lightning_lite.plugins.precision.Precision` class. Otherwise, please open"
         " an issue on the Lightning GitHub repository with your use case."
     )
