@@ -8,8 +8,7 @@ import torch
 from torch import Tensor
 
 import lightning.pytorch as pl
-from lightning.lite.utilities.enums import PrecisionType
-from lightning.lite.utilities.types import _LRScheduler, ReduceLROnPlateau
+from lightning.fabric.utilities.types import LRScheduler, ReduceLROnPlateau
 from lightning.pytorch.strategies.strategy import Strategy, TBroadcast
 from lightning.pytorch.utilities.data import extract_batch_size
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
@@ -193,7 +192,7 @@ class HivemindStrategy(Strategy):
     def setup(self, trainer: "pl.Trainer") -> None:
         self.model_to_device()
         super().setup(trainer)
-        if self.precision_plugin.precision in (PrecisionType.HALF, PrecisionType.MIXED):
+        if self.precision_plugin.precision == "16":
             self.precision_plugin.scaler = hivemind.GradScaler()
 
     def _initialize_hivemind(self) -> None:
@@ -312,7 +311,7 @@ class HiveMindScheduler:
 
     base_lrs: List[float]
 
-    def __init__(self, optimizer: "hivemind.Optimizer", scheduler: _LRScheduler) -> None:
+    def __init__(self, optimizer: "hivemind.Optimizer", scheduler: LRScheduler) -> None:
         # copy most of the `Scheduler` methods into this instance. `__del__` is skipped in case the scheduler has
         # implemented custom logic which we would not want to call on destruction of the `HiveMindScheduler`
         self.__dict__ = {k: v for k, v in scheduler.__dict__.items() if k not in ("step", "__del__")}
