@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@ from lightning.pytorch.accelerators.accelerator import Accelerator
 from lightning.pytorch.accelerators.cpu import CPUAccelerator
 from lightning.pytorch.accelerators.cuda import CUDAAccelerator
 from lightning.pytorch.accelerators.hpu import HPUAccelerator
-from lightning.pytorch.accelerators.ipu import IPUAccelerator
+from lightning.pytorch.accelerators.ipu import _IPU_AVAILABLE, IPUAccelerator
 from lightning.pytorch.accelerators.mps import MPSAccelerator
 from lightning.pytorch.accelerators.tpu import TPUAccelerator
 from lightning.pytorch.plugins import (
@@ -81,7 +81,6 @@ from lightning.pytorch.strategies.ddp_spawn import _DDP_FORK_ALIASES
 from lightning.pytorch.strategies.horovod import _HOROVOD_AVAILABLE
 from lightning.pytorch.tuner.auto_gpu_select import pick_multiple_gpus
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
-from lightning.pytorch.utilities.imports import _IPU_AVAILABLE
 from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation, rank_zero_info, rank_zero_warn
 
 log = logging.getLogger(__name__)
@@ -109,7 +108,7 @@ class AcceleratorConnector:
         sync_batchnorm: bool = False,
         benchmark: Optional[bool] = None,
         replace_sampler_ddp: bool = True,
-        deterministic: Optional[Union[bool, _LITERAL_WARN]] = False,
+        deterministic: Optional[Union[bool, _LITERAL_WARN]] = None,
         auto_select_gpus: Optional[bool] = None,  # TODO: Remove in v2.0.0
         num_processes: Optional[int] = None,  # TODO: Remove in v2.0.0
         tpu_cores: Optional[Union[List[int], str, int]] = None,  # TODO: Remove in v2.0.0
