@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,6 +34,7 @@ from lightning.pytorch.callbacks.rich_model_summary import RichModelSummary
 from lightning.pytorch.callbacks.timer import Timer
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
 from lightning.pytorch.utilities.imports import _PYTHON_GREATER_EQUAL_3_8_0, _PYTHON_GREATER_EQUAL_3_10_0
+from lightning.pytorch.utilities.model_helpers import is_overridden
 from lightning.pytorch.utilities.rank_zero import rank_zero_info
 
 _log = logging.getLogger(__name__)
@@ -82,6 +83,7 @@ class CallbackConnector:
             self._configure_fault_tolerance_callbacks()
 
         self.trainer.callbacks.extend(_configure_external_callbacks())
+        _validate_callbacks_list(self.trainer.callbacks)
 
         # push all model checkpoint callbacks to the end
         # it is important that these are the last callbacks to run
@@ -290,3 +292,18 @@ def _configure_external_callbacks() -> List[Callback]:
         )
         external_callbacks.extend(callbacks_list)
     return external_callbacks
+
+
+def _validate_callbacks_list(callbacks: List[Callback]) -> None:
+    stateful_callbacks = [cb for cb in callbacks if is_overridden("state_dict", instance=cb)]
+    seen_callbacks = set()
+    for callback in stateful_callbacks:
+        if callback.state_key in seen_callbacks:
+            raise RuntimeError(
+                f"Found more than one stateful callback of type `{type(callback).__name__}`. In the current"
+                " configuration, this callback does not support being saved alongside other instances of the same type."
+                f" Please consult the documentation of `{type(callback).__name__}` regarding valid settings for"
+                " the callback state to be checkpointable."
+                " HINT: The `callback.state_key` must be unique among all callbacks in the Trainer."
+            )
+        seen_callbacks.add(callback.state_key)
