@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ from torch.utils.data.dataloader import (
 from typing_extensions import TypedDict
 
 import lightning.pytorch as pl
-from lightning.lite.utilities.types import _Stateful
+from lightning.fabric.utilities.types import _Stateful
 from lightning.pytorch.utilities.distributed import _collect_states_on_rank_zero
 from lightning.pytorch.utilities.enums import _FaultTolerantMode, AutoRestartBatchKeys
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
