@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from lightning.lite.utilities.exceptions import MisconfigurationException  # noqa: F401
+from lightning.fabric.utilities.exceptions import MisconfigurationException  # noqa: F401
 
 
 class DeadlockDetectedException(Exception):
