@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,11 +20,11 @@ from typing import Any, cast, Dict, List, Optional, Tuple, Union
 import numpy as np
 import torch
 import torch.nn as nn
-from lightning_utilities.core.rank_zero import WarningCache
 from torch import Tensor
 from torch.utils.hooks import RemovableHandle
 
 import lightning.pytorch as pl
+from lightning.pytorch.utilities.rank_zero import WarningCache
 
 log = logging.getLogger(__name__)
 warning_cache = WarningCache()
@@ -340,14 +340,14 @@ def _format_summary_table(
     # Formatting
     s = "{:<{}}"
     total_width = sum(col_widths) + 3 * n_cols
-    header = [s.format(c[0], l) for c, l in zip(cols, col_widths)]
+    header = [s.format(c[0], w) for c, w in zip(cols, col_widths)]
 
     # Summary = header + divider + Rest of table
     summary = " | ".join(header) + "\n" + "-" * total_width
     for i in range(n_rows):
         line = []
-        for c, l in zip(cols, col_widths):
-            line.append(s.format(str(c[1][i]), l))
+        for c, w in zip(cols, col_widths):
+            line.append(s.format(str(c[1][i]), w))
         summary += "\n" + " | ".join(line)
     summary += "\n" + "-" * total_width
 
