@@ -21,9 +21,9 @@ from lightning.pytorch.utilities import rank_zero_deprecation
 def inner_f(queue: Queue, func: Callable, *args: Any, **kwargs: Any) -> None:  # pragma: no cover
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.xla_device.inner_f` has been deprecated in v1.8.0 and will be"
-        " removed in v1.10.0. This class is internal but you can copy over its implementation."
+        " removed in v2.0.0. This class is internal but you can copy over its implementation."
     )
-    from lightning.lite.accelerators.tpu import _inner_f
+    from lightning.fabric.accelerators.tpu import _inner_f
 
     return _inner_f(queue, func, *args, **kwargs)
 
@@ -31,9 +31,9 @@ def inner_f(queue: Queue, func: Callable, *args: Any, **kwargs: Any) -> None:  #
 def pl_multi_process(func: Callable) -> Callable:
     rank_zero_deprecation(
         "`lightning.pytorch.utilities.xla_device.pl_multi_process` has been deprecated in v1.8.0 and will be"
-        " removed in v1.10.0. This class is internal but you can copy over its implementation."
+        " removed in v2.0.0. This class is internal but you can copy over its implementation."
     )
-    from lightning.lite.accelerators.tpu import _multi_process
+    from lightning.fabric.accelerators.tpu import _multi_process
 
     return _multi_process(func)
 
@@ -42,14 +42,14 @@ class XLADeviceUtils:
     def __init__(self) -> None:
         rank_zero_deprecation(
             "`lightning.pytorch.utilities.xla_device.XLADeviceUtils` has been deprecated in v1.8.0 and will be"
-            " removed in v1.10.0. This class is internal."
+            " removed in v2.0.0. This class is internal."
         )
 
     @staticmethod
     def xla_available() -> bool:
         rank_zero_deprecation(
             "`lightning.pytorch.utilities.xla_device.XLADeviceUtils.xla_available` has been deprecated in v1.8.0 and"
-            " will be removed in v1.10.0. This method is internal."
+            " will be removed in v2.0.0. This method is internal."
         )
         from lightning.pytorch.accelerators.tpu import _XLA_AVAILABLE
 
@@ -59,7 +59,7 @@ class XLADeviceUtils:
     def tpu_device_exists() -> bool:
         rank_zero_deprecation(
             "`lightning.pytorch.utilities.xla_device.XLADeviceUtils.tpu_device_exists` has been deprecated in v1.8.0"
-            " and will be removed in v1.10.0. Please use `lightning.pytorch.accelerators.TPUAccelerator.is_available()`"
+            " and will be removed in v2.0.0. Please use `lightning.pytorch.accelerators.TPUAccelerator.is_available()`"
             " instead."
         )
         from lightning.pytorch.accelerators.tpu import TPUAccelerator
